pub struct ParsedPayment {
pub amount_paise: i64,
pub merchant: String,
pub is_income: bool,
pub upi_ref: Option<String>,
pub balance_paise: Option<i64>,
pub account_mask: Option<String>,
pub bank_name: Option<String>,
pub needs_review: bool,
}Expand description
A UPI/bank payment parsed from a notification’s text.
Fields
amount_paise: i64Integer paise (Dart stores a 2dp double; same value, exact).
merchant: Stringis_income: boolTrue when money came IN (received/credited). False for spending.
upi_ref: Option<String>balance_paise: Option<i64>True bank balance extracted from the message, paise.
account_mask: Option<String>bank_name: Option<String>needs_review: boolTrait Implementations
Sourceimpl Clone for ParsedPayment
impl Clone for ParsedPayment
Sourcefn clone(&self) -> ParsedPayment
fn clone(&self) -> ParsedPayment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for ParsedPayment
impl<UT> ConvertError<UT> for ParsedPayment
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for ParsedPayment
impl Debug for ParsedPayment
Sourceimpl<UT> FfiConverter<UT> for ParsedPayment
impl<UT> FfiConverter<UT> for ParsedPayment
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for ParsedPayment
impl<UT> Lift<UT> for ParsedPayment
Sourceimpl<UT> LiftRef<UT> for ParsedPayment
impl<UT> LiftRef<UT> for ParsedPayment
type LiftType = ParsedPayment
Sourceimpl<UT> LiftReturn<UT> for ParsedPayment
impl<UT> LiftReturn<UT> for ParsedPayment
Sourcetype ReturnType = <ParsedPayment as Lift<UT>>::FfiType
type ReturnType = <ParsedPayment as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for ParsedPayment
impl<UT> Lower<UT> for ParsedPayment
type FfiType = <ParsedPayment as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for ParsedPayment
impl<UT> LowerError<UT> for ParsedPayment
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for ParsedPayment
impl<UT> LowerReturn<UT> for ParsedPayment
Sourcetype ReturnType = <ParsedPayment as Lower<UT>>::FfiType
type ReturnType = <ParsedPayment as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for ParsedPayment
impl PartialEq for ParsedPayment
impl StructuralPartialEq for ParsedPayment
Sourceimpl<UT> TypeId<UT> for ParsedPayment
impl<UT> TypeId<UT> for ParsedPayment